@@ -2,10 +2,9 @@ package Moxy::Plugin::FlashUseImgTag;
 use strict;
 use warnings;
 use base qw/Moxy::Plugin/;
-use HTTP::MobileAgent;
 use HTML::Parser;
 
-sub e: Hook('response_filter_E') {
+sub response_filter :CarrierHook('E') {
     my ( $self, $context, $args ) = @_;
 
     # only for html.
